module Pages.Contact exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Config.Viewport exposing (..)
import Contact.Helpers exposing (..)
import Contact.Methods.Discord exposing (contactDiscord)
import Contact.Methods.Email exposing (contactEmail)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Font as F
import Headers.Helpers exposing (..)
import Headers.Pages.Contact exposing (contactHeader)
import Html
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {currentRoute = contactName}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.map
        (\_ -> NoOp)
        (Effect.sendCmd resetViewport)
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Model -> View Msg
view model =
    { title = contactName
    , attributes = []
    , element = contactContainer
    }


contactContainer : Element msg
contactContainer =
    topLevelContainer contactList


contactList : Element msg
contactList =
    column pageList <|
        List.concat
            [ [ instructionMaker ]
            ]
